@@ -22,14 +22,14 @@ describe "macaddress fact" do
     end
 
     it "should return the macaddress of the first interface" do
-      Facter::Util::Resolution.stubs(:exec).with('/sbin/ifconfig -a').
+      Facter::Util::Resolution.stubs(:exec).with('/sbin/ifconfig -a 2>/dev/null').
         returns(ifconfig_fixture('linux_ifconfig_all_with_multiple_interfaces'))
 
       Facter.value(:macaddress).should == "00:12:3f:be:22:01"
     end
 
     it "should return nil when no macaddress can be found" do
-      Facter::Util::Resolution.stubs(:exec).with('/sbin/ifconfig -a').
+      Facter::Util::Resolution.stubs(:exec).with('/sbin/ifconfig -a 2>/dev/null').
         returns(ifconfig_fixture('linux_ifconfig_no_mac'))
 
       proc { Facter.value(:macaddress) }.should_not raise_error
@@ -38,7 +38,7 @@ describe "macaddress fact" do
 
     # some interfaces dont have a real mac addresses (like venet inside a container)
     it "should return nil when no interface has a real macaddress" do
-      Facter::Util::Resolution.stubs(:exec).with('/sbin/ifconfig -a').
+      Facter::Util::Resolution.stubs(:exec).with('/sbin/ifconfig -a 2>/dev/null').
         returns(ifconfig_fixture('linux_ifconfig_venet'))
 
       proc { Facter.value(:macaddress) }.should_not raise_error
